@@ -12,6 +12,7 @@ class MailboxAdmin(admin.ModelAdmin):
     list_display = (
                 'name',
                 'uri',
+                'from_email',
                 'active',
             )
     actions = [get_new_mail]
@@ -19,7 +20,6 @@ class MailboxAdmin(admin.ModelAdmin):
 class MessageAdmin(admin.ModelAdmin):
     list_display = (
                 'subject',
-                'address',
                 'processed',
                 'mailbox',
                 'outgoing',
@@ -31,7 +31,6 @@ class MessageAdmin(admin.ModelAdmin):
             )
     raw_id_fields = (
             'in_reply_to',
-            'references',
             )
 
 if getattr(settings, 'DJANGO_MAILBOX_ADMIN_ENABLED', True):
